==> guikachu-1.5.0.tar.gz: guikachu-1.5.0/lib/foocanvasmm/tools/extra_defs_gen/generate_defs_foocanvas.cc <==
/* $Id: generate_defs_foocanvas.cc,v 1.2 2004/06/09 20:20:16 cactus Exp $ */

/* generate_defs_libgnomecanvas.h
 *
 * Copyright (C) 2001 The Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gtkmm_generate_extra_defs/generate_extra_defs.h"
#include <libfoocanvas/libfoocanvas.h>
//#include <libgnomecanvas/gnome-canvas-clipgroup.h>

#include <gtk/gtk.h>

int main (int argc, char *argv[])
{
  gtk_init(&argc, &argv);

  std::cout << get_defs( FOO_TYPE_CANVAS_LINE )
            << get_defs( FOO_TYPE_CANVAS_PIXBUF )
            << get_defs( FOO_TYPE_CANVAS_POLYGON )
            << get_defs( FOO_TYPE_CANVAS_RE )
            << get_defs( FOO_TYPE_CANVAS_RECT )
            << get_defs( FOO_TYPE_CANVAS_ELLIPSE )
            << get_defs( FOO_TYPE_CANVAS_ITEM )
            << get_defs( FOO_TYPE_CANVAS_GROUP )
            << get_defs( FOO_TYPE_CANVAS );

  return 0;
}

==> guikachu-1.5.3.tar.gz: guikachu-1.5.3/lib/foocanvasmm/tools/extra_defs_gen/generate_defs_foocanvas.cc <==
/* $Id: generate_defs_foocanvas.cc,v 1.3 2004/06/25 17:15:33 cactus Exp $ */

/* generate_defs_libgnomecanvas.h
 *
 * Copyright (C) 2001 The Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "glibmm_generate_extra_defs/generate_extra_defs.h"
#include <libfoocanvas/libfoocanvas.h>

#include <gtk/gtk.h>

int main (int argc, char *argv[])
{
  gtk_init(&argc, &argv);

  std::cout << get_defs( FOO_TYPE_CANVAS_LINE )
            << get_defs( FOO_TYPE_CANVAS_PIXBUF )
            << get_defs( FOO_TYPE_CANVAS_POLYGON )
            << get_defs( FOO_TYPE_CANVAS_RE )
            << get_defs( FOO_TYPE_CANVAS_RECT )
            << get_defs( FOO_TYPE_CANVAS_ELLIPSE )
            << get_defs( FOO_TYPE_CANVAS_ITEM )
            << get_defs( FOO_TYPE_CANVAS_GROUP )
            << get_defs( FOO_TYPE_CANVAS );

  return 0;
}
